/****************************************************************************
Diese Programm LayGrpAllOnOff schaltet alle Layer oder Gruppen Ein oder Aus.
Dafür wertet es den ihm übergebenen Parameter aus, es kann nur ein Parameter
angegeben werden.

Folgende Parameter können benutzt werden:
	L:ON  - schaltet alle Layer ein
	L:OFF - schaltet alle Layer aus
	G:ON  - schaltet alle Gruppen ein
	G:OFF - schaltet alle Gruppen aus
	
Beispiele:
InterP	.\CIP\LayGrpAllOnOff.cip L:ON
InterP	.\CIP\LayGrpAllOnOff.cip G:OFF
	
Idee aus http://ww3.cad.de/foren/ubb/Forum22/HTML/004349.shtml

(C) 2013 JonCarpenter
Lizenz:  GPL v3

Version: 1.0 vom 2013-10-31
*****************************************************************************/

#include "std.h"
#include "megatyp.h"
#include "megacad.h"

enum e_LGOnOff{ LG_ON, LG_OFF };

//LG_OnOff 
//schaltet in der angegebenen Liste (Layer oder Gruppe)
//alle Elemente je nach Wert von eLGOnOff an oder aus
short LG_OnOff(
		h_LGList    hListHandle,
        t_LayGrpDta	* pItemData,
		ushort		eLGOnOff)
{	
	h_LGItem    hListItem;	//LayerGruppen Element
    ushort      err;		//Fehlernummer
	
	//erstes Item incl. Daten holen (Root)
	hListItem = LG_ItemOp(hListHandle, LGITEM_ROOT, 0, pItemData, LGOP_GETDATA, &err);
	
	//Schleife durch alle Items (bis Item == 0)
	while( hListItem ) 
	{
		//Layer oder Gruppen 
		if( eLGOnOff == LG_ON )
			pItemData->flags |= LGF_ON; 	//einschalten (Bitweise OR verknüpfen)
		else
			pItemData->flags &= ~LGF_ON;	//ausschalten (Bitweise komplement AND verknüpfen)
		
		//geänderte Daten in Liste schreiben
		LG_ItemOp(hListHandle, hListItem, 0, pItemData, LGOP_SETDATA, &err);
		//nächstes Item holen 
		hListItem = LG_ItemOp(hListHandle, hListItem, 0, pItemData, LGOP_LINEARNEXT, &err);
	}
	
	return(0);
}

//Haupprogramm wird von MegaCAD aufgerufen
short MegaMain(
        char * file,
        char * args)
{  
	ushort      err;  		//Fehlernummer
	h_LGList    hLayer;		//Layerliste
	h_LGList	hGroup;		//Groupliste
	t_LayGrpDta tItemData;	//Layer-/Gruppendaten
	
	SetCharSet(GT_ANSI);	//Zeichensatz einstellen
	
	hLayer = LG_CreateList(LGL_LAYER, &err);	//Liste der Layer erzeugen
	hGroup = LG_CreateList(LGL_GROUP, &err);	//Liste der Gruppen erzeugen
    
	if( !strcmp( args, "L:ON") ) LG_OnOff(hLayer, &tItemData, LG_ON);
	if( !strcmp( args, "G:ON") ) LG_OnOff(hGroup, &tItemData, LG_ON);
	if( !strcmp( args, "L:OFF") ) LG_OnOff(hLayer, &tItemData, LG_OFF);
	if( !strcmp( args, "G:OFF") ) LG_OnOff(hGroup, &tItemData, LG_OFF);	

    //die geänderten Layer- und Gruppendaten in MegaCAD eintragen und Handles löschen (Layer=1 + Group=2)
	LG_Replace(hLayer, hGroup, 3);
 
    return(0);
}
